@@ -22,7 +22,7 @@ from python_kemptech_api.exceptions import (
     SubVsCannotCreateSubVs,
     BackupFailed,
     DownloadUserCertFailed,
-    UnauthorizedAccessError)
+    UnauthorizedAccessError, UserAlreadyExistsException)
 from python_kemptech_api.capabilities import CAPABILITIES, DEFAULT
 from .utils import (
     validate_port,
@@ -512,7 +512,11 @@ class LoadMaster(HttpClient):
         else:
             params['password'] = password
 
-        response = self._get('/useraddlocal', params)
+        try:
+            response = self._get('/useraddlocal', params)
+        except KempTechApiException as e:
+            if str(e) == "User already exists.":
+                raise UserAlreadyExistsException(user, self.ip_address)
         return send_response(response)
 
     def delete_local_user(self, user):
